CAT: Coral Annotation Tool

CAT Coral Annotation Tool

For Structure from Motion (SfM) Orthomosaic coral reef annotation and visualization.

✨

## 1. Project Creator

Drag & drop SfM orthomosaic TIF files to create a new file-based annotation project. Supports multiple TIFs and shapefiles.

Create Project
🪸

## 2. Coral Annotation

Draw lines, boxes, and polygons to annotate coral features. Create and manage annotation projects with JSON storage.

Start Annotating
⚡

## COG Converter

Transform standard GeoTIFF files into Cloud Optimized format for fast web viewing

Open Converter

### ✨ Features

#### 🔄 Auto-Discovery

Automatically detects COG files in your data directory

#### 🚀 Fast Streaming

TiTiler-powered dynamic tile generation for instant viewing

#### 🎯 High Zoom

Zoom up to 2000x for pixel-level inspection

#### 📦 Batch Processing

Convert multiple orthomosaics simultaneously

#### 📁 File-Based Projects

Create and manage annotation projects with JSON storage

#### 🎨 Vector Annotations

Draw polygons, lines, and points with custom attributes

#### 📊 GeoJSON Export

Export annotations in standard GeoJSON format

#### 🗂️ Shapefile Support

Import and work with existing shapefile layers